#!/usr/bin/perl -w
use strict;
use warnings;
use Bio::TreeIO;
use Bio::Tree::TreeFunctionsI;
use Statistics::Descriptive;
my @filenames = glob("*.tree");
foreach my $filename (@filenames) {
  next unless $filename=~m/(?<file>.*).tree/gi;
  my $gene=$+{file};
  print "$gene\n";
  # read in a newick format
  my $treeio = Bio::TreeIO->new(-file => "$filename",-format => "newick",-internal_node_id => 'bootstrap');
  while (my $tree = $treeio->next_tree()) { 
	my @nodes = $tree->get_nodes;
	my $i=0;
    foreach my $node ( @nodes ) {
	   unless ($node->is_Leaf) {
		 $i++;
		 my @child_names;
		 foreach my $child ( $node->get_all_Descendents ) {my $child_name= $child->id;if ( defined $child_name){push @child_names, $child_name if $child_name=~m/\w+/;}}
		 my $child_no=scalar @child_names;
		 my @sorted_child_names=sort { $a cmp $b }@child_names;
		 my $subtaxa=join( ",", @sorted_child_names);
		 my $mrc_length;
		 foreach my $child (@child_names) {
			  my $child_node = $tree->findnode_by_id($child); 
			 $mrc_length = $tree->distance( -nodes => [$node, $child_node] );
			 last;
		 }
		 print "${gene}\tinternode$i\t$mrc_length\t$child_no\n";
		 my $outputs= "${gene}_times.txt";
         open (OUTPUT,">>", $outputs) or die "Can't write the file $outputs: $!";
		 if ($gene=~m/mcmctree/) {
			 print OUTPUT "internode$i\t",$mrc_length*100,"\t$child_no\t$subtaxa\n";
		 }else{print OUTPUT "internode$i\t$child_no\t$subtaxa\t$mrc_length\n";}
         close OUTPUT;
	   }   
    }    
  }
}